@@ -13,14 +13,32 @@ jump_line.enable = true
 config.editor = "vim"
 separator.element = "-"
 separator.color = "white"
-position = ["virtualenv", "python", "package", "docker", "nodejs", "git"]
+position = [
+    "virtualenv",
+    "python",
+    "package",
+    "nodejs",
+    "rust",
+    "golang",
+    "java",
+    "php",
+    "ruby",
+    "elixir",
+    "julia",
+    "dart",
+    "dotnet",
+    "docker",
+    "git"
+    ]
 
 [username]
 enable = false
+symbol = "\\uf007"
 color = "cyan"
 
 [hostname]
 enable = false
+symbol = "\\ue0a2"
 color = "magenta"
 prefix.color = "white"
 prefix.text = "at"
@@ -62,8 +80,16 @@ color = "green"
 error.symbol = "\\uf553"
 error.color = "red"
 
+[python]
+symbol = "\\uf81f"
+color = "yellow"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
 [package]
-enable = true
+enable = false
 symbol = "\\uf8d6"
 color = "red"
 prefix.color = "white"
@@ -71,31 +97,95 @@ prefix.text = "is"
 
 [docker]
 symbol = "\\uf308"
-color = "blue"
+color = "cyan"
 prefix.color = "white"
 prefix.text = "on"
-version.enable = true
+version.enable = false
 version.micro.enable = true
 
 [nodejs]
 symbol = "\\uf898"
 color = "green"
 prefix.color = "white"
-prefix.text = "on"
-version.enable = true
+prefix.text = "via"
+version.enable = false
 version.micro.enable = true
 
-[python]
-symbol = "\\uf81f"
-color = "yellow"
+[rust]
+symbol = "\\ue7a8"
+color = "red"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[golang]
+symbol = "\\ue627"
+color = "cyan"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[php]
+symbol = "\\ue608"
+color = "magenta"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[dart]
+symbol = "\\ue798"
+color = "cyan"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[java]
+symbol = "\\ue256"
+color = "red"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[elixir]
+symbol = "\\ue62d"
+color = "blue"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[julia]
+symbol = "\\ue624"
+color = "blue"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
+[dotnet]
+symbol = "\\ue77f"
+color = "cyan"
 prefix.color = "white"
 prefix.text = "via"
 version.enable = true
 version.micro.enable = true
 
+[ruby]
+symbol = "\\ue21e"
+color = "red"
+prefix.color = "white"
+prefix.text = "via"
+version.enable = false
+version.micro.enable = true
+
 [virtualenv]
-enable = true
-symbol = "\\ufcc2"
+enable = false
+symbol = "\\uf7c9"
 involved = "()"
 color = "yellow"
 prefix.color = "white"
@@ -106,7 +196,7 @@ normal.enable = true
 text = "venv"
 
 [timer]
-enable = true
+enable = false
 symbol = "\\uf43a"
 color = "blue"
 seconds.enable = false
