@@ -14,9 +14,9 @@ def get_virtualenv_name():
 class Virtualenv:
     def __init__(self, config):
         from .lib.utils import symbol_ssh, element_spacing
+        # Thread.__init__(self)
 
         self.config = config
-        self.venv_enable = config["virtualenv"]["enable"]
         self.venv_symbol = symbol_ssh(config["virtualenv"]["symbol"], "")
         self.venv_involved = config["virtualenv"]["involved"]
         self.venv_color = config["virtualenv"]["color"]
@@ -31,7 +31,7 @@ class Virtualenv:
         involved_prefix = ""
         involved_suffix = ""
 
-        if self.venv_enable and "VIRTUAL_ENV" in os_environ:
+        if "VIRTUAL_ENV" in os_environ:
             env_prefix = (
                 f"{Color(self.venv_prefix_color)}"
                 f"{self.venv_prefix_text}{Color().NONE}"
@@ -55,3 +55,12 @@ class Virtualenv:
                 )
             return str(virtualenv)
         return ""
+
+
+def virtualenv(config):
+    import concurrent.futures
+
+    with concurrent.futures.ThreadPoolExecutor() as executor:
+        future = executor.submit(Virtualenv, config)
+        return_value = future.result()
+        return return_value
