@@ -1,7 +1,5 @@
 from subprocess import call as subprocess_call
 
-# from zshpower.utils.check import is_tool, tools_requirements
-
 
 def reload_zsh():
     subprocess_call("exec zsh", shell=True)
@@ -19,22 +17,26 @@ def change_shell():
             printer("Canceled by user", foreground=FG.WARNING)
 
 
-def shell_command(cmd):
-    from subprocess import PIPE, Popen as subprocess_popen
-
-    p = subprocess_popen(
-        cmd, shell=True, stdout=PIPE, stderr=PIPE, universal_newlines=True
-    )
-    output, err = p.communicate()
-    return output.replace("\n", ""), err
-
-
-# # TODO: This may be for the future, but not now.
-# #
+# # TODO: DEPRECATED
 # def bash_command(cmd):
+#     from subprocess import Popen as subprocess_popen
+
 #     subprocess_popen(["/bin/bash", "-c", cmd])
 
+
+# def shell_command(cmd):
+#     from subprocess import PIPE, Popen as subprocess_popen
+
+#     p = subprocess_popen(
+#         cmd, shell=True, stdout=PIPE, stderr=PIPE, universal_newlines=True
+#     )
+#     output, err = p.communicate()
+#     return output.replace("\n", ""), err
+
+
 # def systemctl_is_active(service):
+#     from subprocess import PIPE, Popen as subprocess_popen
+
 #     process = subprocess_popen(
 #         ["systemctl", "is-active", service], stdout=PIPE, universal_newlines=True
 #     )
